@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2012 Mirai Solutions GmbH
+# Copyright (C) 2010-2013 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,23 +22,38 @@
 #
 # Reading named regions from an Excel file
 # 
-# Author: Martin Studer, Mirai Solutions GmbH
+# Authors:  Martin Studer, Mirai Solutions GmbH
+#           Thomas Themel, Mirai Solutions GmbH
+#           Nicola Lambiase, Mirai Solutions GmbH
 #
 #############################################################################
 
 setGeneric("readNamedRegion",
 	function(object, name, header = TRUE, rownames = NULL, colTypes = character(0),
 			forceConversion = FALSE, dateTimeFormat = getOption("XLConnect.dateTimeFormat"),
-			check.names = TRUE) standardGeneric("readNamedRegion"))
+			check.names = TRUE, useCachedValues = FALSE, keep=NULL, drop=NULL) standardGeneric("readNamedRegion"))
+
 
 setMethod("readNamedRegion", 
 	signature(object = "workbook"), 
 	function(object, name, header = TRUE, rownames = NULL, colTypes = character(0),
 			forceConversion = FALSE, dateTimeFormat = getOption("XLConnect.dateTimeFormat"),
-			check.names = TRUE) {
+			check.names = TRUE, useCachedValues = FALSE, keep=NULL, drop=NULL) {
+
 		# returns a list of RDataFrameWrapper Java object references
+		sheet = as.vector(extractSheetName(getReferenceFormula(object, name)))
+		namedim = matrix(as.vector(t(getReferenceCoordinates(object, name))), nrow=4, byrow=FALSE)
+		startRow = namedim[1,]
+		startCol = namedim[2,]
+		endRow = namedim[3,]
+		endCol = namedim[4,]
+		numcols = endCol-startCol+1
+
+		subset <- getColSubset(object, sheet, startRow, endRow, startCol, endCol, header, numcols, keep, drop)
 		dataFrame <- xlcCall(object, "readNamedRegion", name, header, .jarray(classToXlcType(colTypes)), 
-				forceConversion, dateTimeFormat, SIMPLIFY = FALSE)
+				forceConversion, dateTimeFormat, useCachedValues, subset, SIMPLIFY = FALSE)
+		
+
     # get data.frames from Java
     dataFrame = lapply(dataFrame, dataframeFromJava, check.names = check.names)
 		# extract rownames
