@@ -102,8 +102,7 @@ test.writeWorksheetToFile <- function() {
 	cdf <- data.frame(
 			"Column.A" = c(1, 2, 3, NA, 5, 6, 7, 8, NA, 10),
 			"Column.B" = c(-4, -3, NA, -1, 0, NA, NA, 3, 4, 5),
-			"Column.C" = c("Anna", "", 
-					NA, "", NA, "$!?&%", "(2@~'^*#|)", "{}[]:,;-_<>", "\\sadf\n\nv", "a b c"),
+			"Column.C" = c("Anna", "???", NA, "", NA, "$!?&%", "(?2@?~?'^*#|)", "{}[]:,;-_<>", "\\sadf\n\nv", "a b c"),
 			"Column.D" = c(pi, -pi, NA, sqrt(2), sqrt(0.3), -sqrt(pi), exp(1), log(2), sin(2), -tan(2)),
 			"Column.E" = c(TRUE, TRUE, NA, NA, FALSE, FALSE, TRUE, NA, FALSE, TRUE),
 			"Column.F" = c("High", "Medium", "Low", "Low", "Low", NA, NA, "Medium", "High", "High"),
@@ -112,7 +111,7 @@ test.writeWorksheetToFile <- function() {
 			# NOTE: Column.I is automatically converted to POSIXct!!!
 			"Column.I" = rep(c(as.POSIXlt(Sys.time()), as.POSIXlt(Sys.time()) + 3523523, NA, as.POSIXlt(Sys.time()) + 838239), length = 10),
 			"Column.J" = rep(c(as.POSIXct(Sys.time()), as.POSIXct(Sys.time()) + 436322, NA, as.POSIXct(Sys.time()) - 1295022), length = 10),
-			stringsAsFactors = F
+			stringsAsFactors = FALSE
 	)
 	cdf[["Column.F"]] <- factor(cdf[["Column.F"]])
 	cdf[["Column.F"]] <- ordered(cdf[["Column.F"]], levels = c("Low", "Medium", "High"))
