@@ -64,44 +64,31 @@ public class App
 {
     public static void main( String[] args ) throws Exception
     {
-        Workbook wbx = Workbook.getWorkbook("test.xlsx", true);
-        wbx.createSheet("test");
-        wbx.createName("test", "test!$A$1", false);
-        wbx.writeNamedRegion(new DataFrame(), "test", false);
-        wbx.save();
-       
-        if(1 == 1) return;
+        // Workbook wbx = Workbook.getWorkbook("C:/Users/mstuder/Desktop/OI-LIFEEXTRACT-RBC 12 Q2-V04.xls", false);
+        // DataFrame dfx = wbx.readWorksheet("FinalData", true, null);
         
-        /* Performance measurements */
-        int nrows = 10000, ncols = 100;
-
-        File f = new File("C:/Users/mstuder/Documents/perf.xls");
-        if(f.exists()) f.delete();
-
-        long start = System.currentTimeMillis();
-
-        DataFrame dfx = new DataFrame();
-        for(int i = 0; i < ncols; i++) {
-            ArrayList<Double> v = new ArrayList<Double>(nrows);
-            for(int j = 0; j < nrows; j++)
-                v.add(Math.random());
-
-            dfx.addColumn(Integer.toString(i), DataType.Numeric, v);
-        }
-
-        long end = System.currentTimeMillis();
-        System.out.println("Data creation: " + (end - start));
-
-        Workbook wb = Workbook.getWorkbook(f, true);
-        wb.createSheet("MyData");
-        start = System.currentTimeMillis();
-        wb.writeWorksheet(dfx, "MyData", true);
-        end = System.currentTimeMillis();
-        System.out.println("Write worksheet: " + (end - start));
-        start = System.currentTimeMillis();
-        wb.save();
-        end = System.currentTimeMillis();
-        System.out.println("Save: " + (end - start));
+        Workbook wbx = Workbook.getWorkbook("C:/Users/mstuder/Documents/R/win-library/2.15/XLConnect/unitTests/resources/testWorkbookReadWorksheet.xlsx", false);
+        CellStyle csx = wbx.createCellStyle("mystyle");
+        wbx.setCellStyle("asfd", csx);
+        DataFrame dfx = wbx.readWorksheet("VariableNames", true);
+        printDataFrame(dfx);
+        
+        /*
+        Workbook wbx = Workbook.getWorkbook("C:/Users/mstuder/Desktop/test.xlsx", false);
+        
+        DataFrame dfx2 = wbx.readWorksheet("test1", 17, 1, 22, 9, false, false, true); // 17, 1, 22, 9
+        System.out.println("Columns: " + dfx2.columns());
+        System.out.println("Rows: " + dfx2.rows());
+        printDataFrame(dfx2);
+        */
+        
+        // printDataFrame(dfx);
+        // DataFrame dfx1 = wbx.readWorksheet("FinalData", 7, 5, 231, 5, true, null);
+        // printDataFrame(dfx1);
+        // DataFrame dfx2 = wbx.readWorksheet("FinalData", 6, 5, 10, 5, true, null);
+        // printDataFrame(dfx2);
+        
+        if(1 == 1) return;
 
         
         /*
