@@ -113,9 +113,9 @@ public final class RWorkbookWrapper {
     }
 
     public RDataFrameWrapper readNamedRegion(String name, boolean header, String[] colTypes,
-            boolean forceConversion, String dateTimeFormat) {
+            boolean forceConversion, String dateTimeFormat, boolean takeCached, int [] subset) {
         DataFrame dataFrame = workbook.readNamedRegion(name, header, fromString(colTypes),
-                forceConversion, dateTimeFormat);
+                forceConversion, dateTimeFormat, takeCached, subset);
         return new RDataFrameWrapper(dataFrame);
     }
 
@@ -128,16 +128,18 @@ public final class RWorkbookWrapper {
     }
 
     public RDataFrameWrapper readWorksheet(int worksheetIndex, int startRow, int startCol, int endRow, int endCol, 
-            boolean header, String[] colTypes, boolean forceConversion, String dateTimeFormat) {
+            boolean header, String[] colTypes, boolean forceConversion, String dateTimeFormat, boolean takeCached, int [] subset,
+            boolean autofitRow, boolean autofitCol) {
         DataFrame dataFrame = workbook.readWorksheet(worksheetIndex, startRow, startCol, endRow, endCol, header,
-                fromString(colTypes), forceConversion, dateTimeFormat);
+                fromString(colTypes), forceConversion, dateTimeFormat, takeCached, subset, autofitRow, autofitCol);
         return new RDataFrameWrapper(dataFrame);
     }
 
     public RDataFrameWrapper readWorksheet(String worksheet, int startRow, int startCol, int endRow, int endCol, 
-            boolean header, String colTypes[], boolean forceConversion, String dateTimeFormat) {
+            boolean header, String colTypes[], boolean forceConversion, String dateTimeFormat, boolean takeCached, int [] subset,
+            boolean autofitRow, boolean autofitCol) {
         DataFrame dataFrame = workbook.readWorksheet(worksheet, startRow, startCol, endRow, endCol, header,
-                fromString(colTypes), forceConversion, dateTimeFormat);
+                fromString(colTypes), forceConversion, dateTimeFormat, takeCached, subset, autofitRow, autofitCol);
         return new RDataFrameWrapper(dataFrame);
     }
 
@@ -228,7 +230,7 @@ public final class RWorkbookWrapper {
         throw new IllegalArgumentException("Cell style " + name + " does not exist");
     }
 
-    public void setMissingValue(String[] value) {
+    public void setMissingValue(Object[] value) {
         workbook.setMissingValue(value);
     }
 
@@ -275,6 +277,10 @@ public final class RWorkbookWrapper {
     public void setCellStyle(int sheetIndex, int row, int col, RCellStyleWrapper cellStyle) {
         workbook.setCellStyle(sheetIndex, row, col, cellStyle.cellStyle);
     }
+    
+    public void setCellStyle(String formula, RCellStyleWrapper cellStyle) {
+        workbook.setCellStyle(formula, cellStyle.cellStyle);
+    }
 
     public void setColumnWidth(int sheetIndex, int columnIndex, int width) {
         workbook.setColumnWidth(sheetIndex, columnIndex, width);
@@ -379,6 +385,15 @@ public final class RWorkbookWrapper {
         return workbook.getLastRow(sheetName);
     }
 
+    public int getLastColumn(int sheetIndex) {
+        return workbook.getLastColumn(sheetIndex);
+    }
+
+    public int getLastColumn(String sheetName) {
+        return workbook.getLastColumn(sheetName);
+    }
+
+
     public void appendNamedRegion(RDataFrameWrapper data, String name, boolean header) {
         workbook.appendNamedRegion(data.dataFrame, name, header);
     }
@@ -454,4 +469,16 @@ public final class RWorkbookWrapper {
     public void setSheetColor(String sheetName, int color) {
         workbook.setSheetColor(sheetName, color);
     }
+    
+    public int[] getBoundingBox(int sheetIndex, int startRow, int startCol, int endRow, int endCol,
+            boolean autofitRow, boolean autofitCol) {
+	return workbook.getBoundingBox(sheetIndex, startRow, startCol, endRow, endCol,
+                autofitRow, autofitCol);
+    }
+    
+    public int[] getBoundingBox(String sheetName, int startRow, int startCol, int endRow, int endCol,
+            boolean autofitRow, boolean autofitCol) {
+	return workbook.getBoundingBox(sheetName, startRow, startCol, endRow, endCol,
+                autofitRow, autofitCol);
+    }
 }
